pub type CacheFlashReg = RegValueT<CacheFlashReg_SPEC>;Expand description
Cache Flash program size and base address register
Aliased Type
pub struct CacheFlashReg { /* private fields */ }Implementations
Sourceimpl CacheFlashReg
impl CacheFlashReg
Sourcepub fn flash_region_base(
self,
) -> RegisterField<16, 0xffff, 1, 0, u16, u16, CacheFlashReg_SPEC, RW>
pub fn flash_region_base( self, ) -> RegisterField<16, 0xffff, 1, 0, u16, u16, CacheFlashReg_SPEC, RW>
These bits corresponds with the Flash region base address bits [31:16]. Default value is ‘0x1600’. The Flash region base address bits [31:25] are fixed to ‘0x16’ and bits [17:16] are fixed to ‘0x0’. These register bits are retained. Note 1: The updated value takes effect only after a software reset. Note 2 The Flash region base address setting depends on the chosen Flash region size.
Sourcepub fn flash_region_offset(
self,
) -> RegisterField<4, 0xfff, 1, 0, u16, u16, CacheFlashReg_SPEC, RW>
pub fn flash_region_offset( self, ) -> RegisterField<4, 0xfff, 1, 0, u16, u16, CacheFlashReg_SPEC, RW>
Flash region offset address (in words). This value is added to the Flash (CPU) address bits [13:2]. These register bits are retained. Note 1: The updated value takes effect only after a software reset.
Sourcepub fn flash_region_size(
self,
) -> RegisterField<0, 0x7, 1, 0, u8, u8, CacheFlashReg_SPEC, RW>
pub fn flash_region_size( self, ) -> RegisterField<0, 0x7, 1, 0, u8, u8, CacheFlashReg_SPEC, RW>
Flash region size. Default value is ‘6’ (0.5 MBytes). 0 = 32 MBytes, 1 = 16 MBytes, 2 = 8 MBytes, 3 = 4 MBytes, 4 = 2 MBytes, 5 = 1 MBytes, 6 = 0.5 MBytes, 7 = 0.25 MBytes. These register bits are retained. Note 1: The updated value takes effect only after a software reset. Note 2: See for the max. region (program) size the memory map.